@@ -144,6 +144,15 @@ class clLocale:
                 'xkblayout':'pt,us',
                 'language':'pt',
         },
+    #Romanian
+    'ro_RO' : {
+                'locale':'ro_RO.UTF-8',
+                'keymap':'ro_win',
+                'dumpkeys_charset':'',
+                'consolefont':'lat2-16',
+                'xkblayout':'ro,us',
+                'language':'ro',
+        },
     #Russian
     'ru_RU' : {
                 'locale':'ru_RU.UTF-8',
